@@ -1,11 +1,16 @@
 """This module contains the main logic for tootbot."""
+import asyncio
+import logging
 import sys
 import time
 
-from alive_progress import alive_bar
+from outdated import check_outdated
 from rich import print as rprint
+from tqdm import tqdm
 
+from . import __package_name__
 from . import __version__
+from . import PROGRESS_BAR_FORMAT
 from .collect import get_secrets
 from .collect import LinkedMediaHelper
 from .collect import RedditHelper
@@ -14,7 +19,7 @@ from .monitoring import HealthChecks
 from .publish import MastodonPublisher
 
 
-def main() -> None:
+async def main() -> None:
     """Main / Overall Logic of tootbot.
 
     :param: None
@@ -23,54 +28,51 @@ def main() -> None:
     config = Configuration()
 
     rprint(f"Welcome to Tootbot ({__version__})")
+    check_updates()
 
-    secrets = get_secrets(logger=config.bot.logger)
-    MastodonPublisher.get_secrets(
-        mastodon_domain=config.mastodon_config.domain, logger=config.bot.logger
-    )
+    secrets = get_secrets()
+    MastodonPublisher.get_secrets(mastodon_domain=config.mastodon_config.domain)
 
     title = "Setting up shop "
-    with alive_bar(
-        title=f"{title:.<60}",
-        manual=True,
-        enrich_print=False,
-        dual_line=True,
+    with tqdm(
+        desc=f"{title:.<60}",
+        total=1,
+        unit="s",
+        ncols=120,
+        bar_format=PROGRESS_BAR_FORMAT,
     ) as progress_bar:
-
-        progress_bar.text = "Connecting to Mastodon instance ..."
         mastodon_publisher = MastodonPublisher(config=config)
-        progress_bar(0.4120)  # pylint: disable=not-callable
+        progress_bar.update(0.4120)
 
-        progress_bar.text = "Connecting to Healthchecks ..."
         healthcheck = HealthChecks(config=config)
-        progress_bar(0.4122)  # pylint: disable=not-callable
+        progress_bar.update(0.0002)
 
-        progress_bar.text = "Connecting to Reddit ..."
         reddit = RedditHelper(config=config, api_secret=secrets["reddit"])
-        progress_bar(0.4130)  # pylint: disable=not-callable
+        progress_bar.update(0.0008)
 
-        progress_bar.text = "Connecting to Imgur and Gfycat ..."
         media_helper = LinkedMediaHelper(
             config=config,
             gfycat_secrets=secrets["gfycat"],
             imgur_secrets=secrets["imgur"],
         )
-        progress_bar(1.0)  # pylint: disable=not-callable
+        progress_bar.update(1 - 0.4130)
+
+    logger = logging.getLogger("Tootbot")
 
     # Run the main script
     while True:
         if config.health.enabled:
             healthcheck.check_start()
 
-        reddit.get_all_reddit_posts()
+        await reddit.get_all_reddit_posts()
         reddit.winnow_reddit_posts()
-        mastodon_publisher.make_post(reddit.posts, reddit, media_helper)
+        await mastodon_publisher.make_post(reddit.posts, reddit, media_helper)
 
         if config.health.enabled:
             healthcheck.check_ok()
 
         if config.bot.run_once_only:
-            config.bot.logger.debug(
+            logger.debug(
                 "Exiting because RunOnceOnly is set to %s", config.bot.run_once_only
             )
             sys.exit(0)
@@ -88,25 +90,50 @@ def main() -> None:
             if sleep_time > config.mastodon_config.throttling_max_delay:
                 sleep_time = config.mastodon_config.throttling_max_delay
 
-        config.bot.logger.debug("Sleeping for %s seconds", sleep_time)
+        logger.debug("Sleeping for %s seconds", sleep_time)
 
         rprint(" ")
         bar_title = "Sleeping before next toot"
-        with alive_bar(
-            title=f"{bar_title:.<60}",
+        with tqdm(
+            desc=f"{bar_title:.<60}",
             total=sleep_time,
-            enrich_print=False,
-            stats=False,
-            monitor="{count}/{total} seconds",
-            elapsed=False,
+            unit="s",
+            ncols=120,
+            bar_format=PROGRESS_BAR_FORMAT,
         ) as progress_bar:
             for _i in range(sleep_time):
                 time.sleep(1)
-                progress_bar()  # pylint: disable=not-callable
+                progress_bar.update()
+                # progress_bar()  # pylint: disable=not-callable
 
         rprint(" ")
-        config.bot.logger.debug("Restarting main process...")
+        logger.debug("Restarting main process...")
+
+
+def check_updates() -> None:
+    """Check if there is a newer version of MastodonAmnesia available on
+    PyPI."""
+    is_outdated = False
+    try:
+        is_outdated, pypi_version = check_outdated(
+            package=__package_name__,
+            version=__version__,
+        )
+    except ValueError:
+        rprint(
+            "[yellow]Notice - Your version is higher than last published version on PyPI"
+        )
+    if is_outdated:
+        rprint(
+            f"[bold][red]!!! New version of Tootbot ({pypi_version}) "
+            f"is available on PyPI.org !!!\n"
+        )
+
+
+def start_main() -> None:
+    """Starts actual main processing using async."""
+    asyncio.run(main())
 
 
 if __name__ == "__main__":
-    main()
+    start_main()
