@@ -28,6 +28,7 @@ from gfycat.error import GfycatClientError
 from imgurpython import ImgurClient
 from imgurpython.helpers.error import ImgurClientError
 from PIL import Image as PILImage
+from PIL import UnidentifiedImageError
 from rich import print as rprint
 from tqdm.asyncio import tqdm
 
@@ -502,12 +503,15 @@ class LinkedMediaHelper:
                 progress_label="Downloading Imgur image",
             )
 
-            # Imgur will sometimes return a single-frame thumbnail
-            # instead of a GIF, so we need to check for this
-            if saved_paths and (
-                file_extension != ".gif" or self._check_imgur_gif(saved_paths)
-            ):
-                imgur_paths.append(saved_paths)
+            try:
+                # Imgur will sometimes return a single-frame thumbnail
+                # instead of a GIF, so we need to check for this
+                if saved_paths and (
+                    file_extension != ".gif" or self._check_imgur_gif(saved_paths)
+                ):
+                    imgur_paths.append(saved_paths)
+            except UnidentifiedImageError:
+                continue
 
             if len(imgur_paths) == max_images:
                 break
